/* Copyright 2001-2004 Roger Dingledine. */
/* See LICENSE for licensing information */
/* $Id: tor_main.c,v 1.7 2004/11/29 22:25:31 nickm Exp $ */
const char tor_main_c_id[] = "$Id: tor_main.c,v 1.7 2004/11/29 22:25:31 nickm Exp $";

/**
 * \file tor_main.c
 * \brief Entry point for tor binary.
 **/

int tor_main(int argc, char *argv[]);

/** We keep main() in a separate file so that our unit tests can use
 * functions from main.c)
 */
int main(int argc, char *argv[])
{
  return tor_main(argc, argv);
}

